﻿--=====================================================================================================================
-- Script de creació de la base de dades utilitzada per a l'aplicació GIPRA
-- TFC-J2EE 
-- Projecte: Gestió i Informació de la Planificació de Rutes Aèries (G.I.P.R.A)
--=====================================================================================================================

--DROP DATABASE "GIPRA";

--Creació de la base de dades
--CREATE DATABASE "GIPRA" WITH ENCODING='UTF8' OWNER=postgres CONNECTION LIMIT=-1;

--=====================================================================================================================

-- Creació de taules
BEGIN WORK;
SET TRANSACTION READ WRITE;


CREATE TABLE Pais
(
  idPais integer NOT NULL,
  nomPais VARCHAR(25), 
  CONSTRAINT pk_Pais PRIMARY KEY (idPais)
);


CREATE TABLE Ciutat
(
  idCiutat integer NOT NULL,
  nomCiutat VARCHAR(25), 
  idPais integer NOT NULL, 
  CONSTRAINT pk_Ciutat PRIMARY KEY (idCiutat),
  CONSTRAINT fk_CiutatPais FOREIGN KEY (idPais) REFERENCES Pais(idPais)	
);


CREATE TABLE Empleat
(
  idEmpleat integer NOT NULL,
  tipusEmpleat VARCHAR(25) NOT NULL,
  docIdentificatiu VARCHAR(25) UNIQUE NOT NULL,
  nom VARCHAR(25) NOT NULL,
  cognom1 VARCHAR(25) NOT NULL,
  cognom2 VARCHAR(25) NOT NULL,
  adreca VARCHAR(25) NOT NULL,
  ciutat integer NOT NULL,
  pais integer NOT NULL,
  dataAlta date, 
  usuariAlta VARCHAR(25), 
  dataModificacio date, 
  usuariModificacio VARCHAR(25), 
  dataBaixa date, 
  usuariBaixa VARCHAR(25),
  CONSTRAINT pk_Empleat PRIMARY KEY (idEmpleat),
  CONSTRAINT fk_EmpleatCiutat FOREIGN KEY (ciutat) REFERENCES Ciutat(idCiutat),
  CONSTRAINT fk_EmpleatPais FOREIGN KEY (pais) REFERENCES Pais(idPais)
);


CREATE TABLE Usuari
(
  idUsuari integer NOT NULL,
  tipusUsuari VARCHAR(25) NOT NULL,
  login VARCHAR(25) UNIQUE NOT NULL,
  contrasenya VARCHAR(25) NOT NULL,
  eMail VARCHAR(25) NOT NULL,
  estatEnSistema VARCHAR(1) NOT NULL,
  dataAlta date, 
  usuariAlta VARCHAR(25), 
  dataModificacio date, 
  usuariModificacio VARCHAR(25), 
  dataBaixa date, 
  usuariBaixa VARCHAR(25),
  CONSTRAINT pk_Usuari PRIMARY KEY (idUsuari),
  CONSTRAINT fk_UsuariEmpleat FOREIGN KEY (idUsuari) REFERENCES Empleat(idEmpleat)
);


CREATE TABLE Aeroport
(
  idAeroport integer NOT NULL, 
  codiAeroport VARCHAR(25) UNIQUE NOT NULL, 
  nomAeroport VARCHAR(25) NOT NULL, 
  idCiutat  integer NOT NULL, 
  CONSTRAINT pk_Aeroport PRIMARY KEY (idAeroport),
  CONSTRAINT fk_AeroportCiutat FOREIGN KEY (idCiutat) REFERENCES Ciutat(idCiutat)
);	


CREATE TABLE Ruta
(
  idRuta integer NOT NULL,
  codiRuta VARCHAR(25) UNIQUE NOT NULL,
  aeroport1 integer NOT NULL,
  aeroport2 integer NOT NULL,
  estatEnSistema VARCHAR(1) NOT NULL,
  CONSTRAINT pk_Ruta PRIMARY KEY (idRuta),
  CONSTRAINT fk_RutaAeroport1 FOREIGN KEY (aeroport1) REFERENCES Aeroport(idAeroport),
  CONSTRAINT fk_RutaAeroport2 FOREIGN KEY (aeroport2) REFERENCES Aeroport(idAeroport),
  CONSTRAINT rutaUnica UNIQUE (aeroport1,aeroport2)
);


CREATE SEQUENCE Ruta_idRuta_seq
  START WITH 1
  INCREMENT BY 1
  NO MINVALUE
  NO MAXVALUE
  CACHE 1;

ALTER SEQUENCE Ruta_idRuta_seq OWNED BY Ruta.idRuta;
SELECT pg_catalog.setval('Ruta_idRuta_seq', 1, false);
ALTER TABLE Ruta ALTER COLUMN idRuta SET DEFAULT nextval('Ruta_idRuta_seq'::regclass);


CREATE TABLE Vol
(
  idVol integer NOT NULL, 
  codiVol VARCHAR(25) UNIQUE NOT NULL,
  idRuta integer,
  CONSTRAINT pk_Vol PRIMARY KEY (idVol),
  CONSTRAINT fk_VolRuta FOREIGN KEY (idRuta) REFERENCES Ruta(idRuta)
);


CREATE TABLE Aeronau
(
  idAeronau integer NOT NULL, 
  fabricant VARCHAR(25) NOT NULL,
  model VARCHAR(25) NOT NULL,
  idVol integer UNIQUE NOT NULL, 
  CONSTRAINT pk_Aeronau PRIMARY KEY (idAeronau),
  CONSTRAINT fk_AeronauVol FOREIGN KEY (idVol) REFERENCES Vol(idVol)
);	
	

CREATE TABLE Tripulant
(
  idTripulant integer NOT NULL, 
  tipus VARCHAR(25) NOT NULL,
  idVol integer,
  CONSTRAINT pk_Tripulant PRIMARY KEY (idTripulant),
  CONSTRAINT fk_TripulantEmpleat FOREIGN KEY (idTripulant) REFERENCES Empleat(idEmpleat),
  CONSTRAINT fk_TripulantVol FOREIGN KEY (idVol) REFERENCES Vol(idVol)
);


COMMIT;